@@ -1,8 +1,8 @@
-# Copyright 2012-2015 M. Andersen and L. Vandenberghe.
+# Copyright 2012-2021 M. Andersen and L. Vandenberghe.
 # Copyright 2010-2011 L. Vandenberghe.
 # Copyright 2004-2009 J. Dahl and L. Vandenberghe.
 # 
-# This file is part of CVXOPT version 1.1.8.
+# This file is part of CVXOPT.
 #
 # CVXOPT is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -913,7 +913,7 @@ else:
     # 
     # where Yk = mat(yk) if diag is 'N' and Yk = diag(yk) if diag is 'D'.
 
-    if diag is 'N':
+    if diag == 'N':
         maxm = max([0] + dims['s'])
         A = matrix(0.0, (maxm, maxm))
 
@@ -963,7 +963,7 @@ if use_C:
   sinv = misc_solvers.sinv
 else:
   def sinv(x, y, dims, mnl = 0):   
-    """
+    r"""
     The inverse product x := (y o\ x), when the 's' components of y are 
     diagonal.
     """
